==> 0.0.1.tar.gz: ios/Classes/AlicloudImpinteractionLiveroomPlugin.m <==
#import "AlicloudImpinteractionLiveroomPlugin.h"

#import "AIRBDEnvironments.h"
#import "AIRBDLiveRoomViewController.h"

@implementation AlicloudImpinteractionLiveroomPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"alicloud_impinteraction_liveroom"
            binaryMessenger:[registrar messenger]];
  AlicloudImpinteractionLiveroomPlugin* instance = [[AlicloudImpinteractionLiveroomPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    if ([@"getPlatformVersion" isEqualToString:call.method]) {
        result([@"iOS sth" stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
    } else if ([@"getBatteryLevel" isEqualToString:call.method]) {
        result([@"iOS battery" stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
    } else if ([@"init" isEqualToString:call.method]) {
        NSDictionary *param = @{
            @"userId": call.arguments[@"userId"],
            @"appId": call.arguments[@"appId"],
            @"appKey": call.arguments[@"appKey"],
            @"serverHost": call.arguments[@"serverHost"],
            @"serverSecret": call.arguments[@"serverSecret"],
            };
        [self init:param];
        result([@"iOS init" stringByAppendingString:call.arguments[@"userId"]]);
    } else if ([@"setUp" isEqualToString:call.method]) {
        NSDictionary *param = @{
            @"liveId": call.arguments[@"liveId"],
            };
        [self setUp:param];
        result([@"iOS setUp" stringByAppendingString:call.arguments[@"liveId"]]);
    } else {
        result(FlutterMethodNotImplemented);
    }
}

- (void)init: (NSDictionary*) param{
    [AIRBDEnvironments shareInstance]._userId = [param valueForKey:@"userId"];
    [AIRBDEnvironments shareInstance]._appId = [param valueForKey:@"appId"];
    [AIRBDEnvironments shareInstance]._appKey = [param valueForKey:@"appKey"];
    [AIRBDEnvironments shareInstance]._serverHost = [param valueForKey:@"serverHost"];
    [AIRBDEnvironments shareInstance]._serverSecret = [param valueForKey:@"serverSecret"];
}

- (void)setUp: (NSDictionary*) param{
    NSString *liveId = [param valueForKey:@"liveId"];
    [self navToLiveroom:liveId];
}

- (void)navToLiveroom: (NSString*) liveId{
    NSLog(@"nav to liveroom:%@", liveId);
    
    NSString *userId = [AIRBDEnvironments shareInstance]._userId;
    
    AIRBDLiveRoomViewController* vc = [[AIRBDLiveRoomViewController alloc] initWithUserID:userId liveId:nil role:AIRBDLiveRoomUserRoleAnchor title:@"直播"];
    
    UIWindow *window = [UIApplication sharedApplication].keyWindow;
    UIViewController *windowRootVC = (UIViewController *) window.rootViewController;
    
    UINavigationController *navController = [[UINavigationController alloc] initWithRootViewController:vc];
    navController.view.backgroundColor = [UIColor clearColor];
    navController.modalPresentationStyle = UIModalPresentationOverCurrentContext;
    navController.navigationBarHidden = YES;
    navController.hidesBottomBarWhenPushed = YES;
    navController.edgesForExtendedLayout = UIRectEdgeNone;
    [windowRootVC presentViewController:navController animated:true completion:nil];
}

@end

==> 0.0.6.tar.gz: ios/Classes/AlicloudImpinteractionLiveroomPlugin.m <==
#import "AlicloudImpinteractionLiveroomPlugin.h"

#import "AIRBDEnvironments.h"
#import "AIRBDLiveRoomViewController.h"

@implementation AlicloudImpinteractionLiveroomPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"alicloud_impinteraction_liveroom"
            binaryMessenger:[registrar messenger]];
  AlicloudImpinteractionLiveroomPlugin* instance = [[AlicloudImpinteractionLiveroomPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    if ([@"getPlatformVersion" isEqualToString:call.method]) {
        result([@"iOS sth" stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
    } else if ([@"getBatteryLevel" isEqualToString:call.method]) {
        result([@"iOS battery" stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
    } else if ([@"init" isEqualToString:call.method]) {
        NSDictionary *param = @{
            @"userId": call.arguments[@"userId"],
            @"appId": call.arguments[@"appId"],
            @"appKey": call.arguments[@"appKey4iOS"],
            @"serverHost": call.arguments[@"serverHost"],
            @"serverSecret": call.arguments[@"serverSecret"],
            };
        [self init:param];
        result([@"iOS init" stringByAppendingString:call.arguments[@"userId"]]);
    } else if ([@"setUp" isEqualToString:call.method]) {
        NSDictionary *param = @{
            @"liveId": call.arguments[@"liveId"],
            };
        [self setUp:param];
        result([@"iOS setUp" stringByAppendingString:call.arguments[@"liveId"]]);
    } else {
        result(FlutterMethodNotImplemented);
    }
}

- (void)init: (NSDictionary*) param{
    [AIRBDEnvironments shareInstance]._userId = [param valueForKey:@"userId"];
    [AIRBDEnvironments shareInstance]._appId = [param valueForKey:@"appId"];
    [AIRBDEnvironments shareInstance]._appKey = [param valueForKey:@"appKey"];
    [AIRBDEnvironments shareInstance]._serverHost = [param valueForKey:@"serverHost"];
    [AIRBDEnvironments shareInstance]._serverSecret = [param valueForKey:@"serverSecret"];
}

- (void)setUp: (NSDictionary*) param{
    NSString *liveId = [param valueForKey:@"liveId"];
    [self navToLiveroom:liveId];
}

- (void)navToLiveroom: (NSString*) liveId{
    NSLog(@"nav to liveroom:%@", liveId);
    
    NSString *userId = [AIRBDEnvironments shareInstance]._userId;
    
    AIRBDLiveRoomViewController* vc = [[AIRBDLiveRoomViewController alloc] initWithUserID:userId liveId:nil role:AIRBDLiveRoomUserRoleAnchor title:@"直播"];
    
    UIWindow *window = [UIApplication sharedApplication].keyWindow;
    UIViewController *windowRootVC = (UIViewController *) window.rootViewController;
    
    UINavigationController *navController = [[UINavigationController alloc] initWithRootViewController:vc];
    navController.view.backgroundColor = [UIColor clearColor];
    navController.modalPresentationStyle = UIModalPresentationOverCurrentContext;
    navController.navigationBarHidden = YES;
    navController.hidesBottomBarWhenPushed = YES;
    navController.edgesForExtendedLayout = UIRectEdgeNone;
    [windowRootVC presentViewController:navController animated:true completion:nil];
}

@end
